from django.contrib import admin
from django.contrib.admin import SimpleListFilter
from django.utils.translation import gettext_lazy as _
# Register your models here.
from bigsansar.contrib.sites.forms import create_domainform, custompageform
from bigsansar.contrib.sites.models import domains, pages


class domain_filter(SimpleListFilter):
    title = _('Domains')  # a label for our filter
    parameter_name = "domain"  # you can put anything here

    def lookups(self, request, model_admin):
        # This is where you create filter options; we have two:
        qs = model_admin.get_queryset(request).filter(user=request.user.id)

        return qs.values_list('domain_id', 'domain__domain').order_by('domain').distinct()

    def queryset(self, request, queryset):

        # This is where you process parameters selected by use via filter options:
        if self.value():
            return queryset.filter(domain=self.value())


class domainadmin(admin.ModelAdmin):
    form = create_domainform
    list_display = ['domain', 'publish_date', 'visitor']

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        if request.user.is_superuser:
            return qs
        return qs.filter(user=request.user.id)

    def get_form(self, request, obj=None, **kwargs):
        ModelForm = super(domainadmin, self).get_form(request, obj, **kwargs)

        class ModelFormWithRequest(ModelForm):
            def __new__(cls, *args, **kwargs):
                kwargs['request'] = request
                return ModelForm(*args, **kwargs)

        return ModelFormWithRequest


class pageadmin(admin.ModelAdmin):
    form = custompageform
    prepopulated_fields = {"slug": ("title",)}
    list_display = ['title', 'domain', 'publish_date', 'visitor']
    list_filter = (domain_filter,)

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        if request.user.is_superuser:
            return qs
        return qs.filter(user=request.user.id)

    def get_form(self, request, obj=None, **kwargs):
        pageModelForm = super(pageadmin, self).get_form(request, obj, **kwargs)

        class pageModelFormWithRequest(pageModelForm):
            def __new__(cls, *args, **kwargs):
                kwargs['request'] = request
                return pageModelForm(*args, **kwargs)

        return pageModelFormWithRequest


admin.site.register(domains, domainadmin)
admin.site.register(pages, pageadmin)
